mpl\_interactions.image\_segmenter
==================================

.. currentmodule:: mpl_interactions

.. autoclass:: image_segmenter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~image_segmenter.__init__
   
   

   
   
   